@@ -20,6 +20,24 @@ aclocal || {
     exit 1
 }
 
+echo "=== Running autoheader"
+autoheader || {
+    echo "*** Error: autoheader failed."
+    exit 1
+}
+
+echo "=== Running glib-gettextize"
+glib-gettextize -f || {
+    echo "*** Error: glib-gettextize failed."
+    exit 1
+}
+
+echo "=== Running intltoolize"
+intltoolize --automake || {
+    echo "*** Error: intltoolize failed."
+    exit 1
+}
+
 echo "=== Running automake"
 if test "$OSTYPE" = "IRIX" -o "$OSTYPE" = "IRIX64"; then
    AMFLAGS=" --include-deps";
