@@ -1,3 +1,4 @@
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -5,6 +6,7 @@
 #include <errno.h>
 #include <string.h>
 #include <glib.h>
+#include <glib/gi18n.h>
 
 #include "math_util.h"
 #include "str_convert.h"
@@ -587,16 +589,17 @@ const char *mpeg_file_get_desc(mpeg_file *f)
 
 const char *mpeg_file_get_info(mpeg_file *f)
 {
-	static char buf[128];
+	static char buf[256];
 
-	snprintf(buf, 128, "Bit Rate\n%d kbps\n"
-		 "Sample Rate\n%d Hz\n"
-		 "Channel Mode\n%s\n"
-		 "Copyrighted\n%s\n"
-		 "Original\n%s\n",
+	snprintf(buf, sizeof(buf), 
+		 _("Bit Rate\n%d kbps\n"
+		   "Sample Rate\n%d Hz\n"
+		   "Channel Mode\n%s\n"
+		   "Copyrighted\n%s\n"
+		   "Original\n%s\n"),
 		 f->header.bit_rate, f->header.sample_rate, f->header.channel_mode, 
-		 (f->header.copyright ? "Yes" : "No"), 
-		 (f->header.original ? "Yes" : "No"));
+		 (f->header.copyright ? _("Yes") : _("No")), 
+		 (f->header.original ? _("Yes") : _("No")));
 	return buf;
 }
 
